@@ -3,10 +3,11 @@
 import pytest
 import requests
 import tuxbuild.config
+import tuxbuild.exceptions
 
 
 def test_config_FileNotFoundError():
-    with pytest.raises(FileNotFoundError):
+    with pytest.raises(tuxbuild.exceptions.CantGetConfiguration):
         tuxbuild.config.Config(config_path="/nonexistent")
 
 
@@ -50,6 +51,23 @@ token={}
     assert c.get_tuxbuild_env() == c.tuxbuild_env
 
 
+def test_config_file_no_token(tmp_path):
+    contents = """
+[default]
+"""
+    config_file = tmp_path / "config.ini"
+    config_file.write_text(contents)
+    with pytest.raises(tuxbuild.exceptions.TokenNotFound):
+        tuxbuild.config.Config(config_path=config_file)
+
+
+def test_config_file_section(tmp_path):
+    config_file = tmp_path / "config.ini"
+    config_file.write_text("")
+    with pytest.raises(tuxbuild.exceptions.InvalidConfiguration):
+        tuxbuild.config.Config(config_path=config_file)
+
+
 def test_config_file_default(tmp_path, sample_token, sample_url):
     contents = """
 [default]
