@@ -4,7 +4,9 @@ import os
 import tuxbuild.exceptions
 from os.path import expanduser
 import configparser
+import re
 import requests
+import yaml
 import time
 
 
@@ -73,11 +75,16 @@ class Config:
 
     def _get_config_from_config(self, config_path):
         path = expanduser(config_path)
-        open(path, "r")  # ensure file exists and is readable
+        try:
+            open(path, "r")  # ensure file exists and is readable
+        except Exception as e:
+            raise tuxbuild.exceptions.CantGetConfiguration(str(e))
+
         config = configparser.ConfigParser()
+
         config.read(path)
         if not config.has_section(self.tuxbuild_env):
-            raise configparser.NoSectionError(
+            raise tuxbuild.exceptions.InvalidConfiguration(
                 "Error, missing section [{}] from config file '{}'".format(
                     self.tuxbuild_env, path
                 )
@@ -119,3 +126,58 @@ class Config:
                     time.sleep(2 ** i)  # exponential backoff
             else:
                 r.raise_for_status()  # Some unexpected status that's not caught
+
+
+InvalidConfiguration = tuxbuild.exceptions.InvalidConfiguration
+
+
+class BuildSetConfig:
+    def __init__(self, set_name, filename=None):
+        self.set_name = set_name
+        if filename:
+            self.filename = filename
+        else:
+            self.filename = os.path.expanduser("~/.config/tuxbuild/builds.yaml")
+        self.entries = []
+        self.__load_config__()
+
+    def __load_config__(self):
+        filename = self.filename
+        set_name = self.set_name
+        try:
+            if re.match(r"^https?://", str(filename)):
+                contents = self.__fetch_remote_config__(filename)
+            else:
+                contents = open(filename).read()
+            config = yaml.safe_load(contents)
+        except (FileNotFoundError, yaml.loader.ParserError) as e:
+            raise InvalidConfiguration(str(e))
+        if not config:
+            raise InvalidConfiguration(
+                f"Build set configuration in {filename} is empty"
+            )
+        if "sets" not in config:
+            raise InvalidConfiguration('Missing "sets" key')
+        for set_config in config["sets"]:
+            if set_config["name"] == set_name:
+                if "builds" in set_config:
+                    self.entries = set_config["builds"]
+                    if not self.entries:
+                        raise InvalidConfiguration(
+                            f'Build list is empty for set "{set_name}"'
+                        )
+                    return
+                else:
+                    raise InvalidConfiguration(
+                        f'No "builds" field defined for set "{set_name}"'
+                    )
+        raise InvalidConfiguration(f'No build set named "{set_name}" in {filename}')
+
+    def __fetch_remote_config__(self, url, retries=3, sleep=3):
+        result = requests.get(url)
+        if result.status_code != 200:
+            if retries == 0 or result.status_code // 500 != 1:
+                raise InvalidConfiguration(f"Unable to retrieve {url}: {result.reason}")
+            time.sleep(sleep)
+            return self.__fetch_remote_config__(url, retries - 1, sleep * 2)
+        return result.text
